import {
  Entity,
  PrimaryKey,
  Property,
  ManyToOne,
} from '@mikro-orm/core';
import { Note } from '../note/note.entity';
import { RoomSession } from '../room/roomSession.entity';



/**
 * Represents a tracked activity entity.
 */
@Entity({ tableName: 'activities' })
export class Activity {
  @PrimaryKey()
  id!: number;

  @Property()
  userId!: string;

  @ManyToOne()
  roomSession: RoomSession;

  @Property()
  activity!: string;

  @Property({nullable: true})
  numericValue?: number;

  @ManyToOne({ onDelete: 'cascade', hidden: true, nullable: true })
  note?: Note;

  @Property()
  timestamp: Date = new Date();


  /**
   * Constructor to create a new tracked activity instance.
   * @param userId - The user's id.
   * @param room - The associated Room entity.
   * @param activity - The activities user triggers.
   */
    constructor(userId: string, roomSession: RoomSession, activity: string) {
        this.userId = userId;
        this.roomSession = roomSession;
        this.activity = activity;
        }
    
    }