import { Injectable } from '@nestjs/common';
import { EntityManager } from '@mikro-orm/core';
import { InjectRepository } from '@mikro-orm/nestjs';
import { EntityRepository } from '@mikro-orm/mysql';
import { Activity } from './activities.entity';
import { RoomSession } from '../room/roomSession.entity';
import { RoomSessionUser } from '../room/roomSessionUser.entity';
import { SessionPointsService } from '../points/sessionPoints.service';

export enum ActivityType {
  NOTE_CREATE = 'note.create',
  NOTE_UPDATE = 'note.update',
  NOTE_DELETE = 'note.delete',
  NOTE_DELETE_CHARS = 'note.delete.chars',
  WHITEBOARD = 'whiteboard',
  WHITEBOARD_ERASER_USE = 'whiteboard.eraser.use',
  VIDEO_ON = 'video.on',
  VIDEO_OFF = 'video.off',
  AUDIO_ON = 'audio.on',
  AUDIO_OFF = 'audio.off',
  AUDIO_TALKING = 'audio.talking',
  AUDIO_NOT_TALKING = 'audio.nottalking',
  BROWSER_OPEN = 'browser.open',
  BROWSER_CLOSE = 'browser.close',
  BROWSER_MOUSE = 'browser.mouse',
  BROWSER_KEY = 'browser.key',
}

/**
 * A service responsible for managing to track the activities.
 */
@Injectable()
export class ActivitiesService {
  /**
    * Initializes the ActivitiesService.
    * @param em - The EntityManager instance provided by MikroORM.
    * @param repository - The repository for the Activity entity.
    */
  /**
   * Initializes the service with a manager and repository.
   */
  constructor(
    private readonly em: EntityManager,
    @InjectRepository(Activity)
    private readonly repository: EntityRepository<Activity>,
    private readonly sessionPointsService: SessionPointsService,
  ) { }


  public async addNewActivity(userId: string, roomSession: RoomSession, activity: string, numericValue?: number) {
    if (await this.em.findOne(RoomSessionUser, { userId: userId, roomSession: roomSession })) {
      const trackingActivity = new Activity(userId, roomSession, activity);
      await this.em.persistAndFlush(trackingActivity);
      this.sessionPointsService.calculatePoints(roomSession);
      return trackingActivity;
    }
  }
}
  
