import { MikroOrmModule } from '@mikro-orm/nestjs';
import { Module } from '@nestjs/common';
import { AuthModule } from './auth/auth.module';
import { UserModule } from './user/user.module';
import { IsUniqueConstraint } from './common/constraints/unique';
import { ConfigModule } from '@nestjs/config';
import { CategoryModule } from './category/category.module';
import { RoomModule } from './room/room.module';
import { ExistsConstraint } from './common/constraints/exists';
import { ChannelModule } from './channel/channel.module';
import { BrowserModule } from './browser/browser.module';
import { EventEmitterModule } from '@nestjs/event-emitter';
import { ActivitiesModule } from './activities/activities.module';
import { SessionPointsModule } from './points/sessionPoints.module';

/**
 * Main application module where other modules are imported and configured.
 */
@Module({
  imports: [
    MikroOrmModule.forRoot(),
    ConfigModule.forRoot(),
    EventEmitterModule.forRoot(),
    AuthModule,
    UserModule,
    CategoryModule,
    RoomModule,
    ChannelModule,
    BrowserModule,
    ActivitiesModule,
    SessionPointsModule,
  ],
  providers: [IsUniqueConstraint, ExistsConstraint],
})
export class AppModule {}
