import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { RoomSessionService } from './roomSession.service';
import { AuthGuard } from '../auth/auth.guard';
import { RoomSessionPointsRequestDto, RoomSessionResponseDto, RoomSessionModeRequestDto } from './roomSession.dto';
import { RoomSession } from './roomSession.entity';
import { ModeType } from './roomSession.service';

@Controller('roomSession')
export class RoomSessionPointsController {
  constructor(
      private readonly roomSession: RoomSessionService) {}

      
      /**
       * Retrieves the total points for a specific session based on its session ID.
       *
       * @param sessionId - The unique identifier of the session whose points are being retrieved.
       * @returns A promise that resolves to an object containing the total points and the session ID.
       */
      @UseGuards(AuthGuard)
      @Get('/:sessionId/points')
      async getPointsBySession(@Param('sessionId') sessionId: number): Promise<RoomSessionPointsRequestDto> {
        const points = await this.roomSession.getallPositivePointsBySession(sessionId);
        return points;
      }
      
      
      /**
       * Retrieves the mode of a specific session based on its session ID.
       *
       * @param sessionId - The unique identifier of the session whose mode is being retrieved.
       * @returns A promise that resolves to an object containing the mode and the session ID.
       */
      @UseGuards(AuthGuard)
      @Get('/:sessionId/mode')
      async getModeBySession(@Param('sessionId') sessionId: number): Promise<RoomSessionModeRequestDto> {
        const modeType = await this.roomSession.assignMode(sessionId);
        return { modeName: modeType, sessionId };
      }
}