import {
  Collection,
    Entity,
    ManyToOne,
    OneToMany,
    PrimaryKey,
    Property,
  } from '@mikro-orm/core';
  import { Room } from './room.entity';
  import { RoomSessionUser } from './roomSessionUser.entity';
  import { Activity } from '../activities/activities.entity';

/**
 * Represents a room session entity that is associated with an active Room.
 */
@Entity({ tableName: 'roomSession' })
export class RoomSession {
  @PrimaryKey()
  id!: number;

  @ManyToOne()
  room!: Room;

  @OneToMany(() => RoomSessionUser, (user) => user.roomSession)
  users = new Collection<RoomSessionUser>(this);

  @Property()
  dateOpened: Date = new Date();

  @Property({ nullable: true })
  dateClosed?: Date;

  @OneToMany(() => Activity, (activity) => activity.roomSession)
  activities = new Collection<Activity>(this);

  @Property()
  modeName?: string;


  constructor(room: Room) {
    this.room = room;
  }
}
