import { Controller, Get, Param, UseGuards } from '@nestjs/common';
import { RoomSessionUserService } from './roomSessionUser.service';
import { AuthGuard } from '../auth/auth.guard';
import { RoomSessionUserPointsResponseDto, RoomSessionUserResponseDto, RoomSessionUserRolesResponseDto } from './roomSessionUser.dto';
import { RoomSessionUser } from './roomSessionUser.entity';
import { RoomSession } from './roomSession.entity';

@Controller('roomSessionUser')
export class RoomSessionUserPointsController {
  constructor(
      private readonly roomSessionUserService: RoomSessionUserService) {}

      
      /**
       * Retrieves the total points for a specific user based on their user ID.
      *
      * @param userId - The unique identifier of the user whose points are being retrieved.
      * @returns A promise that resolves to an object containing the user's total points and their user ID.
      */
  @UseGuards(AuthGuard)
  @Get('/user/:userId')
  async getPointsByRoomSessionUser(@Param('userId') userId: number): Promise<RoomSessionUserPointsResponseDto> {
    const points = await this.roomSessionUserService.getPointsByRoomSessionUser(userId);
    return { ...points, userId };
  }

  /**
   * Assigns a role to a specific user in a room session.
   *
   * @param userId - The unique identifier of the user.
   * @param role - The role to be assigned to the user.
   * @returns A promise that resolves when the role has been successfully assigned.
   */
  @UseGuards(AuthGuard)
  @Get('/:userId/role')
  async getRole(@Param('userId') userId: number): Promise<RoomSessionUserRolesResponseDto> {
    const roles = await this.roomSessionUserService.assignRole(userId);
    const rolesArray = roles.map(role => role.valueOf());
    return { userId, roleNames: rolesArray };
  }
  
}