import { forwardRef, Global, Module } from '@nestjs/common';
import { MikroOrmModule } from '@mikro-orm/nestjs';
import { RoomSessionUserService } from '../room/roomSessionUser.service';
import { RoomSessionUser } from './roomSessionUser.entity';
import { RoomSessionUserPointsController } from './roomSessionUser.controller';
import { SessionPointsModule } from '../points/sessionPoints.module';
import { SessionPoints } from '../points/sessionPoints.entity';
import { RoomSessionModule } from './roomSession.module';
import { RoomSession } from './roomSession.entity';
import { ActivitiesModule } from '../activities/activities.module';

/**
 * A global module that encapsulates features related to room sessions and users.
 */
@Global()
@Module({
    imports: [
        MikroOrmModule.forFeature([RoomSessionUser, SessionPoints, RoomSession]), 
        forwardRef (() => SessionPointsModule),
        forwardRef (() => RoomSessionModule),
        forwardRef (() => ActivitiesModule),
    ],
    providers: [RoomSessionUserService],
    controllers: [RoomSessionUserPointsController],
    exports: [RoomSessionUserService],
})
export class RoomSessionUserModule {}
